@@ -7,7 +7,7 @@ use base qw/ Lire::SimpleStat /;
 use Carp;
 
 use Lire::DataTypes qw/ is_numeric_type format_numeric_type /;
-use Lire::Utils qw/ sql_quote_name /;
+use Lire::Utils qw/ sql_quote_name check_object_param/;
 use Lire::ReportOperator qw/group_data_value/;
 use Lire::Count;
 use Lire::Sum;
@@ -177,7 +177,7 @@ sub _build_avg_query {
 
     my $sum_expr;
     if ( defined $self->{'weight' }) {
-        $sum_expr = sprintf( 'sum(%s*%s)', 
+        $sum_expr = sprintf( 'sum(%s*%s)',
                              sql_quote_name( $self->{'field'} ),
                              sql_quote_name( $self->{'weight'} ) );
     } else {
@@ -186,16 +186,20 @@ sub _build_avg_query {
     $query->add_aggr_field( $self->{'name'} . "_total", $sum_expr );
 
     my $n_expr;
-    if ( defined $self->{'by_fields'} ) {
+    if ( !defined $self->{'by_fields'} ) {
+        $n_expr = 'count(*)';
+    } elsif ( @{$self->{'by_fields'}} == 1 &&
+            is_numeric_type( $self->report_spec()->field( $self->{'by_fields'}[0] )->type() ) )
+    {
+        $n_expr = sprintf( 'sum(%s)', sql_quote_name($self->{'by_fields'}[0]));
+    } else {
         my @fields = map { sql_quote_name( $_ ) } @{ $self->{'by_fields'} };
         $n_expr = sprintf( 'lr_count_uniq(%s)', join (',', @fields) );
-    } else {
-        $n_expr = 'count(*)';
     }
     $query->add_aggr_field( $self->{'name'} . "_n", $n_expr );
-
     $query->add_aggr_field( $self->{'name'},
                             sprintf( '%s/%s', $sum_expr, $n_expr ) );
+    return;
 }
 
 # Overrides Lire::SimpleStat::sql_required_fields
@@ -370,7 +374,7 @@ __END__
 
 =head1 VERSION
 
-$Id: Average.pm,v 1.13 2004/07/02 16:09:24 flacoste Exp $
+$Id: Average.pm,v 1.16 2006/07/23 13:16:27 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -390,7 +394,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =cut
