@@ -11,14 +11,14 @@ sub coalesce {
 }
 
 BEGIN {
-    ($VERSION)  = '$Revision: 1.7 $' =~ m!Revision: ([.\d]+)!;
+    ($VERSION)  = '$Revision: 1.8 $' =~ m!Revision: ([.\d]+)!;
 
     @ISA = qw(Exporter);
     @EXPORT_OK  = qw(ac_info ac_path ac_flags);
 
     %ac = (
         exec_prefix => '${prefix}',
-        prefix => '/home/francis/tests/lire-2.0',
+        prefix => '/usr/local',
         program_transform_name => 's,x,x,',
         bindir => '${exec_prefix}/bin',
         sbindir => '${exec_prefix}/sbin',
@@ -30,29 +30,29 @@ BEGIN {
         libdir => '${exec_prefix}/lib',
         includedir => '${prefix}/include',
         oldincludedir => '/usr/include',
-        infodir => '${prefix}/info',
-        mandir => '${prefix}/man',
+        infodir => '${prefix}/share/info',
+        mandir => '${prefix}/share/man',
         INSTALL_PROGRAM => '${INSTALL}',
         INSTALL_SCRIPT => '${INSTALL}',
         INSTALL_DATA => '${INSTALL} -m 644',
         PACKAGE => 'lire',
-        VERSION => '2.0.1',
-        SHELL => '/bin/sh',
+        VERSION => '2.0.2',
+        SHELL => '/bin/bash',
         CFLAGS => '@CFLAGS@',
         CPPFLAGS => '@CPPFLAGS@',
         CXXFLAGS => '@CXXFLAGS@',
         FFLAGS => '@FFLAGS@',
-        DEFS => '-DPACKAGE_NAME=\"\" -DPACKAGE_TARNAME=\"\" -DPACKAGE_VERSION=\"\" -DPACKAGE_STRING=\"\" -DPACKAGE_BUGREPORT=\"\" -DPACKAGE=\"lire\" -DVERSION=\"2.0.1\" ',
+        DEFS => '-DPACKAGE_NAME=\"\" -DPACKAGE_TARNAME=\"\" -DPACKAGE_VERSION=\"\" -DPACKAGE_STRING=\"\" -DPACKAGE_BUGREPORT=\"\" -DPACKAGE=\"lire\" -DVERSION=\"2.0.2\"',
         LDFLAGS => '@LDFLAGS@',
         LIBS => '',
         PERL => '/usr/bin/perl',
-        LR_PERL5LIB => '/home/francis/tests/lire-2.0/share/perl5',
+        LR_PERL5LIB => '/usr/local/share/perl5',
         GZIP => '/bin/gzip',
         SENDMAIL => '/usr/sbin/sendmail',
         PLOTICUS => '/usr/bin/ploticus',
         TAR => '/bin/tar',
         GHOSTSCRIPT => '/usr/bin/gs',
-        LR_ARCHIVEDIR => '${prefix}/var/lib/lire/data',
+        LR_ARCHIVEDIR => '/usr/local/var/lib/lire/data',
     );
     # calculate the transitive closure of any substitutions
     my $changed;
@@ -100,7 +100,7 @@ override certain parameters.
 
 =head1 VERSION
 
-$Id: Build.pm.in,v 1.7 2004/01/21 07:23:00 wsourdeau Exp $
+$Id: Build.pm.in,v 1.8 2006/07/23 13:16:30 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -120,8 +120,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =head1 AUTHOR
 
