@@ -29,7 +29,7 @@ __END__
 
 =head1 VERSION
 
-$Id: ChartTypeSpec.pm,v 1.1 2004/07/15 16:34:00 flacoste Exp $
+$Id: ChartTypeSpec.pm,v 1.2 2006/07/23 13:16:30 vanbaal Exp $
 
 =head1 AUTHOR
 
@@ -53,7 +53,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
