@@ -156,7 +156,7 @@ Wessel Dankers <wsl@logreport.org>
 
 =head1 VERSION
 
-$Id: Scalar.pm,v 1.14 2004/07/21 15:53:44 flacoste Exp $
+$Id: Scalar.pm,v 1.15 2006/07/23 13:16:30 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -176,7 +176,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
