@@ -246,7 +246,7 @@ __END__
 
 =head1 VERSION
 
-$Id: Value.pm,v 1.16 2004/07/21 15:53:44 flacoste Exp $
+$Id: Value.pm,v 1.17 2006/07/23 13:16:31 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -266,7 +266,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
