@@ -415,6 +415,56 @@ sub sql_expr {
     }
 }
 
+package Lire::FilterExpr::DlfSource;
+
+use base qw/ Lire::FilterExpr /;
+
+use Lire::Utils qw/ sql_quote_name check_param /;
+use Carp;
+
+sub new {
+    my $self  = shift()->SUPER::new( @_ );
+
+    my %args = @_;
+    check_param( $args{'value'}, 'value' );
+
+    $self->value( $args{'value'} );
+
+    return $self;
+}
+
+sub value {
+    my ( $self, $value ) = @_;
+
+    if ( @_ == 2 ) {
+        check_param( $value, 'value' );
+	$self->_validate_value( $value );
+	$self->{'value'} = $value;
+    }
+
+    $self->{'value'};
+}
+
+sub print {
+    croak "Cannot print a Lire::FilterExpr::DlfSource";
+}
+
+sub sql_params {
+    my $self = $_[0];
+
+    unless ( $self->_is_value_a_fieldref( $self->{'value' } ) ) {
+        return [ $self->{'container'}->resolve_param_ref ( $self->{'value' }) ];
+    } else {
+        return [ $self->{'value'} ];
+    }
+}
+
+sub sql_expr {
+    my $self = $_[0];
+
+    return  $self->{'container'}->schema()->sql_table() . ".dlf_source" . " = ?";
+}
+
 package Lire::FilterExpr::Not;
 
 use base qw/ Lire::FilterExpr /;
@@ -589,7 +639,7 @@ Lire::FilterExpr -
 
 =head1 VERSION
 
-$Id: FilterExpr.pm,v 1.30 2004/05/17 17:05:19 wsourdeau Exp $
+$Id: FilterExpr.pm,v 1.32 2006/07/23 13:16:29 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -609,7 +659,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =cut
