@@ -249,7 +249,7 @@ __END__
 
 =head1 VERSION
 
-$Id: First.pm,v 1.13 2004/08/30 03:11:11 flacoste Exp $
+$Id: First.pm,v 1.14 2006/07/23 13:16:29 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -269,7 +269,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =cut
