@@ -170,7 +170,7 @@ FIXME
 
 =head1 VERSION
 
-$Id: I18N.pm,v 1.24 2004/09/03 02:08:28 flacoste Exp $
+$Id: I18N.pm,v 1.25 2006/07/23 13:16:29 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -190,7 +190,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =cut
