@@ -93,7 +93,7 @@ Lire::ReportSpec(3pm), Lire::ReportOperator(3pm), Lire::Aggregator(3pm), Lire::A
 
 =head1 VERSION
 
-$Id: Max.pm,v 1.8 2004/07/01 15:33:20 flacoste Exp $
+$Id: Max.pm,v 1.9 2006/07/23 13:16:29 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -113,7 +113,6 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =cut
