@@ -640,7 +640,7 @@ __END__
 
 =head1 VERSION
 
-$Id: Rangegroup.pm,v 1.22 2004/07/02 16:09:24 flacoste Exp $
+$Id: Rangegroup.pm,v 1.23 2006/07/23 13:16:29 vanbaal Exp $
 
 =head1 COPYRIGHT
 
@@ -660,8 +660,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software 
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html. 
 
 =cut
 
