@@ -8,22 +8,10 @@ use base qw/tests::ConfigCompoundSpecTest/;
 use Lire::Config::TypeSpec;
 use Lire::Config::Object;
 
-sub test_instance {
-    shift->tests::ConfigTypeSpecTest::test_instance( @_ );
-}
-
-sub test_is_instance {
-    shift->tests::ConfigTypeSpecTest::test_is_instance( @_ );
-}
-
 sub type {
     return 'Lire::Config::ObjectSpec';
 }
 
-sub value_type {
-    return 'Lire::Config::Object';
-}
-
 sub additional_new_params {
     return ( 'class' => 'mypackage' );
 }
