@@ -2,16 +2,11 @@ package tests::UIExecutableWidgetTest;
 
 use strict;
 
-no warnings 'redefine';
-
 use base qw/ Lire::Test::TestCase /;
 
 use Lire::Config::TypeSpec;
-
-use Curses::UI;
-use File::Basename qw/ dirname basename /;
-
 use Lire::Test::CursesUIDriver;
+use Curses::UI;
 
 sub set_up {
     my $self = $_[0];
@@ -47,10 +42,8 @@ sub test_new {
 
     my $widget = $self->{'window'}->add( 'exec_widget', 'Lire::UI::ExecutableWidget',
                                          'value' => $self->{'exec_param'} );
-    $self->assert( UNIVERSAL::isa( $widget, 'Lire::UI::FileWidget' ),
-                   "not a Lire::UI::FileWidget instance: $widget" );
-    $self->assert( UNIVERSAL::isa( $widget, 'Lire::UI::ExecutableWidget' ),
-                   "not a Lire::UI::ExecutableWidget instance: $widget" );
+    $self->assert_isa( 'Lire::UI::FileWidget', $widget );
+    $self->assert( 'Lire::UI::ExecutableWidget', $widget );
 }
 
 1;
