@@ -327,7 +327,7 @@ called by lr_log2report:
 
 =head1 VERSION
 
-$Id: SquidAccessDlfConverter.pm,v 1.6 2004/07/22 13:43:45 flacoste Exp $
+$Id: SquidAccessDlfConverter.pm,v 1.7 2006/07/23 13:16:36 vanbaal Exp $
 
 =head1 AUTHORS
 
@@ -352,8 +352,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program (see COPYING); if not, check with
-http://www.gnu.org/copyleft/gpl.html or write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+http://www.gnu.org/copyleft/gpl.html.
 
 =cut
 
